@@ -178,15 +178,11 @@ class HDevEngine(object):
 
         You can control the port via the attribute 'debug_port'.
         """
-        HCkE(_hdevengine_lib.HCenStartDebugServer(
-            ctypes.byref(self._engine_ptr)
-        ))
+        HCkE(_hdevengine_lib.HCenStartDebugServer(self._engine_ptr))
 
     def stop_debug_server(self) -> None:
         """Stops the debug server, resuming execution if stopped."""
-        HCkE(_hdevengine_lib.HCenStopDebugServer(
-            ctypes.byref(self._engine_ptr)
-        ))
+        HCkE(_hdevengine_lib.HCenStopDebugServer(self._engine_ptr))
 
     def set_procedure_path(self, path: str) -> None:
         """
